@@ -60,7 +60,7 @@ class HttpException(SDKException, _rex.HTTPError):
         # TODO(shade) Remove http_status parameter and the ability for response
         # to be None once we're not mocking Session everywhere.
         if not message:
-            if response:
+            if response is not None:
                 message = "{name}: {code}".format(
                     name=self.__class__.__name__,
                     code=response.status_code)
@@ -72,7 +72,7 @@ class HttpException(SDKException, _rex.HTTPError):
         SDKException.__init__(self, message=message)
         _rex.HTTPError.__init__(self, message, response=response)
 
-        if response:
+        if response is not None:
             self.request_id = response.headers.get('x-openstack-request-id')
             self.status_code = response.status_code
         else:
@@ -90,7 +90,7 @@ class HttpException(SDKException, _rex.HTTPError):
         # 'Error', then someone has set a more informative error message
         # and we should use it. If it is 'Error', then we should construct a
         # better message from the information we do have.
-        if not self.url or self.message != 'Error':
+        if not self.url or self.message == 'Error':
             return super(HttpException, self).__str__()
         if self.url:
             remote_error = "{source} Error for url: {url}".format(
@@ -118,6 +118,11 @@ class BadRequestException(HttpException):
     pass
 
 
+class ConflictException(HttpException):
+    """HTTP 409 Conflict."""
+    pass
+
+
 class MethodNotSupported(SDKException):
     """The resource does not support this operation type."""
     def __init__(self, resource, method):
@@ -162,7 +167,9 @@ def raise_from_response(response, error_message=None):
     if response.status_code < 400:
         return
 
-    if response.status_code == 404:
+    if response.status_code == 409:
+        cls = ConflictException
+    elif response.status_code == 404:
         cls = NotFoundException
     elif response.status_code == 400:
         cls = BadRequestException
