@@ -12,7 +12,7 @@
 
 from openstack.network import network_service
 from openstack.network.v2 import tag
-from openstack import resource2 as resource
+from openstack import resource
 
 
 class Network(resource.Resource, tag.TagMixin):
@@ -30,13 +30,14 @@ class Network(resource.Resource, tag.TagMixin):
 
     # NOTE: We don't support query on list or datetime fields yet
     _query_mapping = resource.QueryParameters(
-        'description', 'name', 'project_id', 'status',
+        'description', 'name', 'status',
         ipv4_address_scope_id='ipv4_address_scope',
         ipv6_address_scope_id='ipv6_address_scope',
         is_admin_state_up='admin_state_up',
         is_port_security_enabled='port_security_enabled',
         is_router_external='router:external',
         is_shared='shared',
+        project_id='tenant_id',
         provider_network_type='provider:network_type',
         provider_physical_network='provider:physical_network',
         provider_segmentation_id='provider:segmentation_id',
@@ -113,9 +114,6 @@ class Network(resource.Resource, tag.TagMixin):
     updated_at = resource.Body('updated_at')
     #: Indicates the VLAN transparency mode of the network
     is_vlan_transparent = resource.Body('vlan_transparent', type=bool)
-    #: A list of assocaited tags
-    #: *Type: list of tag strings*
-    tags = resource.Body('tags', type=list)
 
 
 class DHCPAgentHostingNetwork(Network):
