@@ -402,17 +402,20 @@ class TestCase(base.TestCase):
         self.adapter = self.useFixture(rm_fixture.Fixture())
         self.calls = []
         self._uri_registry.clear()
-        self.__do_register_uris([
-            dict(method='GET', uri='https://identity.example.com/',
-                 text=open(self.discovery_json, 'r').read()),
-            dict(method='POST',
-                 uri='https://identity.example.com/v3/auth/tokens',
-                 headers={
-                     'X-Subject-Token': self.getUniqueString('KeystoneToken')},
-                 text=open(os.path.join(
-                     self.fixtures_directory, catalog), 'r').read()
-                 ),
-        ])
+        with open(self.discovery_json, 'r') as discovery_file, \
+            open(os.path.join(
+                self.fixtures_directory, catalog), 'r') as tokens_file:
+            self.__do_register_uris([
+                dict(method='GET', uri='https://identity.example.com/',
+                     text=discovery_file.read()),
+                dict(method='POST',
+                     uri='https://identity.example.com/v3/auth/tokens',
+                     headers={
+                         'X-Subject-Token':
+                         self.getUniqueString('KeystoneToken')},
+                     text=tokens_file.read()
+                     ),
+            ])
         self._make_test_cloud(identity_api_version='3')
 
     def use_keystone_v2(self):
@@ -420,14 +423,18 @@ class TestCase(base.TestCase):
         self.calls = []
         self._uri_registry.clear()
 
-        self.__do_register_uris([
-            dict(method='GET', uri='https://identity.example.com/',
-                 text=open(self.discovery_json, 'r').read()),
-            dict(method='POST', uri='https://identity.example.com/v2.0/tokens',
-                 text=open(os.path.join(
-                     self.fixtures_directory, 'catalog-v2.json'), 'r').read()
-                 ),
-        ])
+        with open(self.discovery_json, 'r') as discovery_file, \
+            open(os.path.join(
+                self.fixtures_directory,
+                'catalog-v2.json'), 'r') as tokens_file:
+            self.__do_register_uris([
+                dict(method='GET', uri='https://identity.example.com/',
+                     text=discovery_file.read()),
+                dict(method='POST',
+                     uri='https://identity.example.com/v2.0/tokens',
+                     text=tokens_file.read()
+                     ),
+            ])
 
         self._make_test_cloud(cloud_name='_test_cloud_v2_',
                               identity_api_version='2.0')
@@ -450,6 +457,23 @@ class TestCase(base.TestCase):
                     status_code=300,
                     text=open(discovery_fixture, 'r').read())
 
+    def get_nova_discovery_mock_dict(
+            self,
+            compute_version_json='compute-version.json',
+            compute_discovery_url='https://compute.example.com/v2.1/'):
+        discovery_fixture = os.path.join(
+            self.fixtures_directory, compute_version_json)
+        return dict(
+            method='GET',
+            uri=compute_discovery_url,
+            text=open(discovery_fixture, 'r').read())
+
+    def get_placement_discovery_mock_dict(self):
+        discovery_fixture = os.path.join(
+            self.fixtures_directory, "placement.json")
+        return dict(method='GET', uri="https://placement.example.com/",
+                    text=open(discovery_fixture, 'r').read())
+
     def get_designate_discovery_mock_dict(self):
         discovery_fixture = os.path.join(
             self.fixtures_directory, "dns.json")
@@ -462,6 +486,20 @@ class TestCase(base.TestCase):
         return dict(method='GET', uri="https://bare-metal.example.com/",
                     text=open(discovery_fixture, 'r').read())
 
+    def get_senlin_discovery_mock_dict(self):
+        discovery_fixture = os.path.join(
+            self.fixtures_directory, "clustering.json")
+        return dict(method='GET', uri="https://clustering.example.com/",
+                    text=open(discovery_fixture, 'r').read())
+
+    def use_compute_discovery(
+            self, compute_version_json='compute-version.json',
+            compute_discovery_url='https://compute.example.com/v2.1/'):
+        self.__do_register_uris([
+            self.get_nova_discovery_mock_dict(
+                compute_version_json, compute_discovery_url),
+        ])
+
     def use_glance(
             self, image_version_json='image-version.json',
             image_discovery_url='https://image.example.com/'):
@@ -474,6 +512,10 @@ class TestCase(base.TestCase):
             self.get_glance_discovery_mock_dict(
                 image_version_json, image_discovery_url)])
 
+    def use_placement(self):
+        self.__do_register_uris([
+            self.get_placement_discovery_mock_dict()])
+
     def use_designate(self):
         # NOTE(slaweq): This method is only meant to be used in "setUp"
         # where the ordering of the url being registered is tightly controlled
@@ -492,6 +534,15 @@ class TestCase(base.TestCase):
         self.__do_register_uris([
             self.get_ironic_discovery_mock_dict()])
 
+    def use_senlin(self):
+        # NOTE(elachance): This method is only meant to be used in "setUp"
+        # where the ordering of the url being registered is tightly controlled
+        # if the functionality of .use_senlin is meant to be used during an
+        # actual test case, use .get_senlin_discovery_mock and apply to the
+        # right location in the mock_uris when calling .register_uris
+        self.__do_register_uris([
+            self.get_senlin_discovery_mock_dict()])
+
     def register_uris(self, uri_mock_list=None):
         """Mock a list of URIs and responses via requests mock.
 
@@ -543,7 +594,7 @@ class TestCase(base.TestCase):
             key = '{method}|{uri}|{params}'.format(
                 method=method, uri=uri, params=kw_params)
             validate = to_mock.pop('validate', {})
-            valid_keys = set(['json', 'headers', 'params'])
+            valid_keys = set(['json', 'headers', 'params', 'data'])
             invalid_keys = set(validate.keys()) - valid_keys
             if invalid_keys:
                 raise TypeError(
