@@ -10,7 +10,7 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
-import testtools
+from openstack.tests.unit import base
 
 from openstack.identity.v3 import role
 
@@ -22,7 +22,7 @@ EXAMPLE = {
 }
 
 
-class TestRole(testtools.TestCase):
+class TestRole(base.TestCase):
 
     def test_basic(self):
         sot = role.Role()
@@ -36,6 +36,15 @@ class TestRole(testtools.TestCase):
         self.assertTrue(sot.allow_delete)
         self.assertTrue(sot.allow_list)
 
+        self.assertDictEqual(
+            {
+                'domain_id': 'domain_id',
+                'name': 'name',
+                'limit': 'limit',
+                'marker': 'marker',
+            },
+            sot._query_mapping._mapping)
+
     def test_make_it(self):
         sot = role.Role(**EXAMPLE)
         self.assertEqual(EXAMPLE['id'], sot.id)
